"clean.graphics" <-
function(funs=NULL,
         package=NULL,
         names=NULL,
         width=600,
         height=600,
         device=postscript,
         format="pbm",
         model.loc=".",
         test.loc=model.loc,
         verbose=FALSE,
         testonly=TRUE) {
  if (is.character(device)) {
    dev.name <- device
  }
  else {
    dev.name <- deparse(substitute(device))
  }
  if (charmatch(dev.name, "postscript", nomatch=FALSE))
    device.fns <- postscript.fns
  else if (charmatch(dev.name, "x11", nomatch=FALSE))
    device.fns <- x11.fns
  else if (charmatch(dev.name, "pdf", nomatch=FALSE))
    device.fns <- pdf.fns
  else
    stop(paste("QC for the", dev.name, "device has not yet been implemented"))
  # format should be character
  format <- as.character(format)
  if (charmatch(format, "pbm", nomatch=FALSE))
    format.fns <- pbm.fns
  else if (charmatch(format, "ps", nomatch=FALSE))
    format.fns <- ps.fns
  else
    stop(paste("Output format", format, "has not yet been implemented"))
  # width and height must be integer
  width <- as.integer(width)
  height <- as.integer(height)
  # model.loc must be character
  model.loc <- as.character(model.loc)
  # Must specify exactly one of funs or package
  if (is.null(funs)) {
    if (is.null(package))
      stop("Must specify one of `funs' or `package'")
    else {
      if (!is.character(package))
        package <- deparse(substitute(package))
      # Omit names beginning with %, [, 
      funs <- ls(paste("package:", package, sep=""),
                 pattern="^[^[%]")
    }
  }
  # funs must be character
  if (!is.character(funs))
    stop("`funs' must be a character vector")
  # names must be NULL or same length as funs
  if (!is.null(names)) {
    if (length(names) != length(funs))
      stop("`names' must be the same length as `funs'")
  }
  count <- 1
  for (i in funs) {
    if (verbose)
      cat("clean.graphics:", i, "\n");
    # Remove all test and possibly model output
    filebasename <- paste(if (is.null(names)) i else names[count],
                          "-", dev.name, "-",
                          width, "x", height, sep="")
    fullmodelfilename <- file.path(model.loc, filebasename)
    fulltestfilename <- file.path(test.loc, filebasename)
    # Let the device clean up if it needs to
    if (!testonly)
      device.fns$clean(model.loc, filebasename, ".save.")
    device.fns$clean(test.loc, filebasename, ".test.")
    # Get lists of files to remove
    # Is list.files sufficiently platform-independent?
    # Looks like it's designed to be
    # (see listfiles in $RHOME/src/main/platform.c)
    modelfiles <- list.files(model.loc,
                             paste("^", filebasename, ".save.*.",
                                   format, sep=""),
                             full.names=TRUE)
    testfiles <- list.files(test.loc,
                            paste("^", filebasename, ".test.*.",
                                  format, sep=""),
                            full.names=TRUE)
    if (!testonly) 
      file.remove(modelfiles)
    file.remove(testfiles)
    # Remove files produced by format-dependent diff
    format.fns$clean(test.loc)
    count <- count + 1
  }
}
