\name{graphicsQC}
\alias{graphicsQC}
\alias{clean.graphics}
\alias{model.graphics}
\alias{test.graphics}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Quality Control Tools for Graphics }
\description{
  These functions provide routines for producing
  a set of model graphical output for specified
  functions, testing graphics output against the model output,
  and removing test and possibly model output files.  
}
\usage{
model.graphics(funs = NULL, package = NULL, names=NULL,
               width = 600, height = 600,
               device = postscript,
               format = "pbm",
               model.loc = ".",
               verbose = FALSE,
               reset.rng = TRUE,
               ...)

test.graphics(funs = NULL, package = NULL, names=NULL, omit=NULL,
              width = 600, height = 600,
              device = postscript, format = "pbm",
              model.loc = ".", test.loc = model.loc,
              verbose = FALSE, quiet = FALSE,
              reset.rng = TRUE,
              ...)

clean.graphics(funs = NULL, package = NULL, names = NULL,
               width = 600, height = 600,
               device = postscript, format = "pbm",
               model.loc = ".", test.loc = model.loc,
               verbose = FALSE, testonly = TRUE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{funs}{ A character vector specifying the names of functions
  to produce test graphical output for. }
\item{package}{ The name of a package -- all functions in the
  package will be tested.  Only one of \code{funs} or \code{package}
can be specified. }
\item{names}{ A character vector specifying the names to use as part
  of the
  filenames for the test output.  This defaults to the function
  names.  If specified, it must be the same length as the \code{funs}
  argument. }
\item{omit}{ A character vector or list.  If a character vector
  then this specifies functions
  to omit.  If a list then character elements specify entire
  functions to omit and named numeric elements specify
  examples within a function to omit.  See the examples below. }
  \item{width}{ The width of the final test output (in pixels). }
  \item{height}{ The height of the final test output (in pixels). }
  \item{device}{ The device to use to produce the initial test output.
  Valid values are: \code{"postscript"}, \code{"pdf"}, and \code{"x11"}. }
  \item{format}{ The format for the final test output.  Valid
    values depend on the device -- some possibilities
    are: \code{"pbm"} (monochrome portable bitmap file format) for
    postscript, pdf and x11 devices;
    \code{"ps"} (postscript format) for the postscript and pdf device.}
\item{model.loc}{ The directory in which to look for the model output. }
  \item{test.loc}{The directory in which to create the test output. }
  \item{verbose}{ If \code{TRUE}, print out progress messages. }
  \item{quiet}{ If \code{TRUE}, do not print out a final result. }
  \item{testonly}{ If \code{TRUE}, remove only test output (i.e., do not
    remove model output). }
  \item{reset.rng}{ If \code{TRUE}, reset the random number generator
    and random seed before running each example.  This will ensure that
    differences from examples that randomly-generate data will not show
    up.  It is useful to set this to \code{FALSE} if you want to
    detect examples of this kind.}
  \item{\dots}{ Additional arguments to the device. }
}
\details{
  The model output is initially produced using the specified device, then
  converted to a final model output (as specified by the
  \code{format} argument).

  The test output is initially produced using the specified device, then
  converted to a final test output (as specified by the
  \code{format} argument).

  The test output is compared, per final output file, with the corresponding
  model output.  If a difference is found, an image of the difference
  is produced (for \code{"bmp"} format at least).

  For each function, the number of final output files, the width, height,
  device, and format must be the same for test and model output before
  the comparison will proceed.

  It is possible to compare the output from functions with different
  names by specifying the \code{names} argument.  This overrides the
  naming of output files, which is based on the function name otherwise.
}
\value{
  \code{model.graphics} is useful for its side-effect, which is
  to create an initial
  output file per function using the device output format (if
  applicable) plus a final output file per page of initial output,
  per function.
  
  \code{test.graphics} produces a
  list containing a description of the differences detected.
  The names of the elements give the
  names of the functions which had examples that differed and the
  element values are numeric vectors indicating which examples
  differed.  See the examples below.
}

\section{WARNING }{
  Function names which start with non-alphanumeric characters (e.g., \code{[},
  \code{\%}, \code{@}, \code{$}, ...), or contain \code{<-} are omitted).
}

\examples{
model.graphics("barplot", model.loc=tempdir())
diffs <- test.graphics("barplot", model.loc=tempdir(), reset.rng=FALSE)
# list(barplot=1:2) as at version 1.6.1
diffs
# Should report no differences
test.graphics("barplot", omit=diffs, model.loc=tempdir())
# Tidy up
clean.graphics("barplot", model.loc=tempdir())
}
\keyword{ utilities }% at least one, from doc/KEYWORDS
